//[mahjong-utils](../../../../index.md)/[mahjongutils.hora](../../index.md)/[RegularHoraHandPattern](../index.md)/[Companion](index.md)

# Companion

[common]\
object [Companion](index.md)

## Functions

| Name | Summary |
|---|---|
| [build](build.md) | [common]<br>fun [build](build.md)(pattern: [RegularHandPattern](../../../mahjongutils.models.hand/-regular-hand-pattern/index.md), agari: [Tile](../../../mahjongutils.models/-tile/index.md), tsumo: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html), selfWind: [Wind](../../../mahjongutils.models/-wind/index.md)? = null, roundWind: [Wind](../../../mahjongutils.models/-wind/index.md)? = null): [Collection](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-collection/index.html)&lt;[RegularHoraHandPattern](../index.md)&gt;<br>构建标准形和牌手牌 |
